@@ -59,7 +59,7 @@ class ViewletManagerGrokker(martian.ClassGrokker):
 
         config.action(
             discriminator=('viewletManager', context, layer, view, name),
-            callable=component.provideAdapter,
+            callable=grokcore.component.provideAdapter,
             args=(factory, (context, layer, view), IViewletManager, name))
         return True
 
@@ -98,7 +98,7 @@ class ViewletGrokker(martian.ClassGrokker):
         config.action(
             discriminator=(
                 'viewlet', context, layer, view, viewletmanager, name),
-            callable=component.provideAdapter,
+            callable=grokcore.component.provideAdapter,
             args=(factory, (context, layer, view, viewletmanager),
                   IViewlet, name))
 
